const mongoose = require('mongoose');

// Function to connect to MongoDB using Mongoose and create collections
async function connectDB() {
  try {
    // Connect using the MongoDB URI from environment variables
    const conn = await mongoose.connect(process.env.MONGO_URI || "mongodb://127.0.0.1:27017/todo_app");
    console.log(`MongoDB connected: ${conn.connection.host}`);

    // Get the database object from the connection
    const db = conn.connection.db;

    // Check if the collections exist and create them if not
    await db.createCollection('users');
    await db.createCollection('todos');
    await db.createCollection('global');

    console.log('Collections created successfully!');
  } catch (err) {
    console.error(`Error: ${err.message}`);
    process.exit(1); // Exit the process with failure if the connection or collection creation fails
  }
}

module.exports = connectDB;